IterInitWithValueFn

Type Alias IterInitWithValueFn 

pub type IterInitWithValueFn = unsafe extern "C" fn(PtrConst) -> PtrMut;
Create a new iterator that iterates over the provided value

Safety

The value parameter must point to aligned, initialized memory of the correct type.