ListPushFn

Type Alias ListPushFn 

pub type ListPushFn = unsafe extern "C" fn(PtrMut, PtrMut);
Push an item to the list

Safety

The list parameter must point to aligned, initialized memory of the correct type. item is moved out of (with core::ptr::read) — it should be deallocated afterwards (e.g. with core::mem::forget) but NOT dropped. Note: item must be PtrMut (not PtrConst) because ownership is transferred and the value may be dropped later, which requires mutable access.